@@ -51,6 +51,7 @@ typedef struct _GncCommodityNamespaceClass gnc_commodity_namespaceClass;
 
 #include <glib.h>
 #include <glib/gi18n.h>
+
 #include "gnc-engine.h"
 
 #ifdef __cplusplus
@@ -99,21 +100,20 @@ GType gnc_commodity_namespace_get_type(void);
  *  only used to populate an option menu in the commodity selection
  *  window.
  */
-#define GNC_COMMODITY_NS_LEGACY "GNC_LEGACY_CURRENCIES"
-#define GNC_COMMODITY_NS_TEMPLATE "template"
+#define GNC_COMMODITY_NS_LEGACY        "GNC_LEGACY_CURRENCIES"
+#define GNC_COMMODITY_NS_TEMPLATE      "template"
 /* The ISO define is deprecated in favor of CURRENCY */
-#define GNC_COMMODITY_NS_ISO    "ISO4217"
-#define GNC_COMMODITY_NS_CURRENCY "CURRENCY"
-#define GNC_COMMODITY_NS_NASDAQ "NASDAQ"
-#define GNC_COMMODITY_NS_NYSE   "NYSE"
-#define GNC_COMMODITY_NS_EUREX  "EUREX"
-#define GNC_COMMODITY_NS_MUTUAL "FUND"
-#define GNC_COMMODITY_NS_AMEX   "AMEX"
-#define GNC_COMMODITY_NS_ASX    "ASX"
-#define GNC_COMMODITY_NS_NONCURRENCY _("All non-currency")
-/* Delay translation of this one, we use it in both translated and untranslated form
-   when presenting the currency related namespace to the user */
-#define GNC_COMMODITY_NS_ISO_GUI N_("Currencies")
+#define GNC_COMMODITY_NS_ISO           "ISO4217"
+#define GNC_COMMODITY_NS_CURRENCY      "CURRENCY"
+#define GNC_COMMODITY_NS_NONCURRENCY "NONCURRENCY"
+
+#define GNC_COMMODITY_NS_NONISO_GUI   NC_("Commodity Type", "All non-currency")
+#define GNC_COMMODITY_NS_ISO_GUI       NC_("Commodity Type", "Currencies")
+
+/** Max fraction is 10^9 because 10^10 would require changing it to an
+ * int64_t.
+ */
+#define GNC_COMMODITY_MAX_FRACTION 1000000000
 
 typedef GList CommodityList;
 
@@ -353,7 +353,7 @@ const char * gnc_commodity_get_mnemonic(const gnc_commodity * cm);
  */
 const char * gnc_commodity_get_namespace(const gnc_commodity * cm);
 
-/** Retrieve the namespace data strucure for the specified commodity.
+/** Retrieve the namespace data structure for the specified commodity.
  *  This will be a pointer to another data structure.
  *
  *  @param cm A pointer to a commodity data structure.
@@ -799,18 +799,18 @@ gboolean gnc_commodity_table_add_default_data(gnc_commodity_table *table, QofBoo
  @{
 */
 
-/** Return the textual name of a namespace data strucure.
+/** Return the textual name of a namespace data structure.
  *
- *  @param ns A pointer to the namespace data strucure.
+ *  @param ns A pointer to the namespace data structure.
  *
  *  @return A pointer to the name of the namespace.  This string is
  *  owned by the engine and should not be freed by the caller. */
 const char * gnc_commodity_namespace_get_name (const gnc_commodity_namespace *ns) ;
 
-/** Return the textual name of a namespace data strucure in a form suitable to
+/** Return the textual name of a namespace data structure in a form suitable to
  * present to the user.
  *
- *  @param ns A pointer to the namespace data strucure.
+ *  @param ns A pointer to the namespace data structure.
  *
  *  @return A pointer to the gui friendly name of the namespace.  This string is
  *  owned by the engine and should not be freed by the caller.
@@ -966,8 +966,8 @@ gboolean gnc_commodity_table_foreach_commodity(const gnc_commodity_table * table
  @{
 */
 
-/** You proably shouldn't be using gnc_commodity_table_new() directly,
- * its for internal use only. You should probably be using
+/** You probably shouldn't be using gnc_commodity_table_new() directly,
+ * it's for internal use only. You should probably be using
  * gnc_commodity_table_get_table()
  */
 gnc_commodity_table * gnc_commodity_table_new(void);
