@@ -57,30 +57,15 @@
 
 #include "gnc-commodity.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /** @name Basic Object Implementation */
 /** @{ */
 
 #define GNC_TYPE_CURRENCY_EDIT	    (gnc_currency_edit_get_type())
-#define GNC_CURRENCY_EDIT(o)	    (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_CURRENCY_EDIT, GNCCurrencyEdit))
-#define GNC_CURRENCY_EDIT_CLASS(k)  (G_TYPE_CHECK_CLASS_CAST ((k), GNC_TYPE_CURRENCY_EDIT, GNCCurrencyEditClass))
-#define GNC_IS_CURRENCY_EDIT(o)	    (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_CURRENCY_EDIT))
-
-typedef struct
-{
-    GtkComboBoxEntry combobox;
-} GNCCurrencyEdit;
-
-typedef struct
-{
-    GtkComboBoxEntryClass combobox;
-} GNCCurrencyEditClass;
-
-/** Return the GType for the GNCCurrencyEdit currency selection widget.
- *
- *  @return A GType value.
- */
-GType gnc_currency_edit_get_type (void);
-
+G_DECLARE_FINAL_TYPE (GNCCurrencyEdit, gnc_currency_edit, GNC, CURRENCY_EDIT, GtkComboBox)
 
 /** Create a new GNCCurrencyEdit widget which can be used to provide
  *  an easy way to enter ISO currency codes.
@@ -114,15 +99,24 @@ void gnc_currency_edit_set_currency (GNCCurrencyEdit *gce,
  */
 gnc_commodity *gnc_currency_edit_get_currency (GNCCurrencyEdit *gce);
 
+
+/** Clear the displayed currency of the widget.
+ *
+ *  This will clear the currency being displayed just like when first created
+ *  but it still returns the default currency as usual
+ *
+ *  @param gce The currency editor widget whose values should be retrieved.
+ */
+void gnc_currency_edit_clear_display (GNCCurrencyEdit *gce);
+
 /** @} */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 /** @} */
 /** @} */
 
-/*
-  Local Variables:
-  c-basic-offset: 8
-  End:
-*/
